@@ -110,7 +110,7 @@
 
 // Type indices
 enum : int {
-    SBK_QT3DEXTRAS_IDX                                       = 0,
+    SBK_Qt3DExtrasQT3DEXTRAS_IDX                             = 0,
     SBK_QT3DEXTRAS_QABSTRACTCAMERACONTROLLER_IDX             = 1,
     SBK_QT3DEXTRAS_QABSTRACTCAMERACONTROLLER_INPUTSTATE_IDX  = 2,
     SBK_QT3DEXTRAS_QABSTRACTSPRITESHEET_IDX                  = 3,
