@@ -46,60 +46,59 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qt3dcore_python.h>
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qframeaction.h>
-#include <qlogicaspect.h>
+#include <Qt3DLogic/qframeaction.h>
+#include <Qt3DLogic/qlogicaspect.h>
 // Conversion Includes - Primitive Types
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QT3DLOGIC_IDX                                            0
-#define SBK_QT3DLOGIC_QFRAMEACTION_IDX                               1
-#define SBK_QT3DLOGIC_QLOGICASPECT_IDX                               2
-#define SBK_Qt3DLogic_IDX_COUNT                                      3
-
+enum : int {
+    SBK_Qt3DLogicQT3DLOGIC_IDX                               = 0,
+    SBK_QT3DLOGIC_QFRAMEACTION_IDX                           = 1,
+    SBK_QT3DLOGIC_QLOGICASPECT_IDX                           = 2,
+    SBK_Qt3DLogic_IDX_COUNT                                  = 3
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_Qt3DLogicTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_Qt3DLogicModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_Qt3DLogicTypeConverters;
 
 // Converter indices
-#define SBK_QT3DLOGIC_QLIST_QOBJECTPTR_IDX                           0 // const QList<QObject* > &
-#define SBK_QT3DLOGIC_QLIST_QBYTEARRAY_IDX                           1 // QList<QByteArray >
-#define SBK_QT3DLOGIC_QVECTOR_QT3DCORE_QNODEPTR_IDX                  2 // QVector<Qt3DCore::QNode* >
-#define SBK_QT3DLOGIC_QVECTOR_QT3DCORE_QENTITYPTR_IDX                3 // QVector<Qt3DCore::QEntity* >
-#define SBK_QT3DLOGIC_QLIST_QVARIANT_IDX                             4 // QList<QVariant >
-#define SBK_QT3DLOGIC_QLIST_QSTRING_IDX                              5 // QList<QString >
-#define SBK_QT3DLOGIC_QMAP_QSTRING_QVARIANT_IDX                      6 // QMap<QString,QVariant >
-#define SBK_Qt3DLogic_CONVERTERS_IDX_COUNT                           7
-
+enum : int {
+    SBK_QT3DLOGIC_QVECTOR_QT3DCORE_QNODEPTR_IDX              = 0, // QVector<Qt3DCore::QNode* >
+    SBK_QT3DLOGIC_QLIST_QOBJECTPTR_IDX                       = 1, // const QList<QObject* > &
+    SBK_QT3DLOGIC_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray >
+    SBK_QT3DLOGIC_QVECTOR_QT3DCORE_QENTITYPTR_IDX            = 3, // QVector<Qt3DCore::QEntity* >
+    SBK_QT3DLOGIC_QLIST_QVARIANT_IDX                         = 4, // QList<QVariant >
+    SBK_QT3DLOGIC_QLIST_QSTRING_IDX                          = 5, // QList<QString >
+    SBK_QT3DLOGIC_QMAP_QSTRING_QVARIANT_IDX                  = 6, // QMap<QString,QVariant >
+    SBK_Qt3DLogic_CONVERTERS_IDX_COUNT                       = 7
+};
 // Macros for type check
 
 namespace Shiboken
