@@ -47,19 +47,19 @@
 #include <sbkpython.h>
 #include <sbkconverter.h>
 // Module Includes
-#include <pyside2_qtwidgets_python.h>
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
+#include <pyside2_qtwidgets_python.h>
 
 // Binded library includes
-#include <qpagesetupdialog.h>
-#include <qprinter.h>
-#include <qprintpreviewdialog.h>
-#include <qprinterinfo.h>
-#include <qprintengine.h>
-#include <qprintdialog.h>
-#include <qprintpreviewwidget.h>
-#include <qabstractprintdialog.h>
+#include <QtPrintSupport/qprintengine.h>
+#include <QtPrintSupport/qprintpreviewwidget.h>
+#include <QtPrintSupport/qprintdialog.h>
+#include <QtPrintSupport/qpagesetupdialog.h>
+#include <QtPrintSupport/qprintpreviewdialog.h>
+#include <QtPrintSupport/qprinterinfo.h>
+#include <QtPrintSupport/qabstractprintdialog.h>
+#include <QtPrintSupport/qprinter.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -121,15 +121,16 @@ enum : int {
     SBK_QTPRINTSUPPORT_QLIST_QWIDGETPTR_IDX                  = 1, // const QList<QWidget* > &
     SBK_QTPRINTSUPPORT_QLIST_INT_IDX                         = 2, // QList<int >
     SBK_QTPRINTSUPPORT_QLIST_QPRINTERINFO_IDX                = 3, // QList<QPrinterInfo >
-    SBK_QTPRINTSUPPORT_QLIST_QPRINTER_DUPLEXMODE_IDX         = 4, // QList<QPrinter::DuplexMode >
-    SBK_QTPRINTSUPPORT_QLIST_QPAGESIZE_IDX                   = 5, // QList<QPageSize >
-    SBK_QTPRINTSUPPORT_QLIST_QPAGEDPAINTDEVICE_PAGESIZE_IDX  = 6, // QList<QPagedPaintDevice::PageSize >
-    SBK_QTPRINTSUPPORT_QPAIR_QSTRING_QSIZEF_IDX              = 7, // QPair<QString,QSizeF >
-    SBK_QTPRINTSUPPORT_QLIST_QPAIR_QSTRING_QSIZEF_IDX        = 8, // QList<QPair< QString,QSizeF > >
-    SBK_QTPRINTSUPPORT_QLIST_QVARIANT_IDX                    = 9, // QList<QVariant >
-    SBK_QTPRINTSUPPORT_QLIST_QSTRING_IDX                     = 10, // QList<QString >
-    SBK_QTPRINTSUPPORT_QMAP_QSTRING_QVARIANT_IDX             = 11, // QMap<QString,QVariant >
-    SBK_QtPrintSupport_CONVERTERS_IDX_COUNT                  = 12
+    SBK_QTPRINTSUPPORT_QLIST_QPRINTER_COLORMODE_IDX          = 4, // QList<QPrinter::ColorMode >
+    SBK_QTPRINTSUPPORT_QLIST_QPRINTER_DUPLEXMODE_IDX         = 5, // QList<QPrinter::DuplexMode >
+    SBK_QTPRINTSUPPORT_QLIST_QPAGESIZE_IDX                   = 6, // QList<QPageSize >
+    SBK_QTPRINTSUPPORT_QLIST_QPAGEDPAINTDEVICE_PAGESIZE_IDX  = 7, // QList<QPagedPaintDevice::PageSize >
+    SBK_QTPRINTSUPPORT_QPAIR_QSTRING_QSIZEF_IDX              = 8, // QPair<QString,QSizeF >
+    SBK_QTPRINTSUPPORT_QLIST_QPAIR_QSTRING_QSIZEF_IDX        = 9, // QList<QPair< QString,QSizeF > >
+    SBK_QTPRINTSUPPORT_QLIST_QVARIANT_IDX                    = 10, // QList<QVariant >
+    SBK_QTPRINTSUPPORT_QLIST_QSTRING_IDX                     = 11, // QList<QString >
+    SBK_QTPRINTSUPPORT_QMAP_QSTRING_QVARIANT_IDX             = 12, // QMap<QString,QVariant >
+    SBK_QtPrintSupport_CONVERTERS_IDX_COUNT                  = 13
 };
 // Macros for type check
 
